@@ -68,6 +68,29 @@ static inline SV* _easyxs_fetch_scalar_return (pTHX_ int count) {
     return ret;
 }
 
+static inline SV** _easyxs_fetch_list_return (pTHX_ int count) {
+    dSP;
+
+    SPAGAIN;
+
+    SV** ret;
+
+    Newx(ret, 1 + count, SV*);
+    ret[count] = NULL;
+
+    while (count-- > 0) {
+        ret[count] = SvREFCNT_inc(POPs);
+    }
+
+    PUTBACK;
+    FREETMPS;
+    LEAVE;
+
+    SAVEFREEPV(ret);
+
+    return ret;
+}
+
 static inline SV* _easyxs_call_method_scalar (pTHX_ SV* object, const char* methname, SV** args) {
     _EASYXS_SET_ARGS(aTHX_ object, args);
 
@@ -90,25 +113,50 @@ static inline SV* _easyxs_call_sv_scalar (pTHX_ SV* cb, SV** args) {
 #define exs_call_sv_scalar(sv, args) \
     _easyxs_call_sv_scalar(aTHX_ sv, args)
 
+static inline SV** _easyxs_call_sv_list (pTHX_ SV* cb, SV** args) {
+    _EASYXS_SET_ARGS(aTHX_ NULL, args);
+
+    int count = call_sv(cb, G_ARRAY);
+
+    return _easyxs_fetch_list_return(aTHX_ count);
+}
+
+#define exs_call_sv_list(sv, args) \
+    _easyxs_call_sv_list(aTHX_ sv, args)
+
+#define _handle_trapped_error(count, err_p) STMT_START { \
+    dSP;                                        \
+    SV* err_tmp = ERRSV;                        \
+    if (SvTRUE(err_tmp)) {                      \
+        while (count--) PERL_UNUSED_VAR(POPs);  \
+                                                \
+        *err_p = err_tmp;                       \
+                                                \
+        PUTBACK;                                \
+        FREETMPS;                               \
+        LEAVE;                                  \
+    }                                           \
+} STMT_END
+
+static inline void _easyxs_call_sv_void_trapped (pTHX_ SV* cb, SV** args, SV** error) {
+    _EASYXS_SET_ARGS(aTHX_ NULL, args);
+
+    int count = call_sv(cb, G_VOID | G_EVAL);
+
+    _handle_trapped_error(count, error);
+}
+
+#define exs_call_sv_void_trapped(sv, args, err_p) \
+    _easyxs_call_sv_void_trapped(aTHX_ sv, args, err_p)
+
 static inline SV* _easyxs_call_sv_scalar_trapped (pTHX_ SV* cb, SV** args, SV** error) {
     _EASYXS_SET_ARGS(aTHX_ NULL, args);
 
     int count = call_sv(cb, G_SCALAR | G_EVAL);
 
-    dSP;
+    _handle_trapped_error(count, error);
 
-    SV* err_tmp = ERRSV;
-    if (SvTRUE(err_tmp)) {
-        while (count--) PERL_UNUSED_VAR(POPs);
-
-        *error = err_tmp;
-
-        PUTBACK;
-        FREETMPS;
-        LEAVE;
-
-        return NULL;
-    }
+    if (SvTRUE(ERRSV)) return NULL;
 
     return _easyxs_fetch_scalar_return(aTHX_ count);
 }
@@ -116,4 +164,19 @@ static inline SV* _easyxs_call_sv_scalar_trapped (pTHX_ SV* cb, SV** args, SV**
 #define exs_call_sv_scalar_trapped(sv, args, err_p) \
     _easyxs_call_sv_scalar_trapped(aTHX_ sv, args, err_p)
 
+static inline SV** _easyxs_call_sv_list_trapped (pTHX_ SV* cb, SV** args, SV** error) {
+    _EASYXS_SET_ARGS(aTHX_ NULL, args);
+
+    int count = call_sv(cb, G_ARRAY | G_EVAL);
+
+    _handle_trapped_error(count, error);
+
+    if (SvTRUE(ERRSV)) return NULL;
+
+    return _easyxs_fetch_list_return(aTHX_ count);
+}
+
+#define exs_call_sv_list_trapped(sv, args, err_p) \
+    _easyxs_call_sv_list_trapped(aTHX_ sv, args, err_p)
+
 #endif
